@@ -1,6 +1,5 @@
 import pika, requests, threading, json, time
 from logzero import logger
-from datetime import datetime
 from pymitter import EventEmitter
 
 class AutoSolve:
@@ -154,7 +153,7 @@ class AutoSolve:
             self.log("Connection attempts unsuccessful", self.ERROR)
 
     def send(self, message, route, exchange):
-        message["createdAt"] = str(datetime.utcnow())
+        message["createdAt"] = round(time.time())
         message_string = json.dumps(message)
         byte_string = message_string.encode()
         return self.channel.basic_publish(exchange=exchange,
